Firebase CLI (GitHub), Firebase projelerini yönetmek, görüntülemek ve bu projelere dağıtım yapmak için çeşitli araçlar sunar.
Firebase CLI'yı kullanmadan önce bir Firebase projesi oluşturun.
KSA'yı ayarlama veya güncelleme
Firebase KSA'yı yükleme
Firebase CLI'yı işletim sisteminize, deneyim düzeyinize ve/veya kullanım alanınıza uygun bir yöntemle yükleyebilirsiniz. CLI'yı nasıl yüklediğinizden bağımsız olarak aynı işlevlere ve firebase komutuna erişebilirsiniz.
Windows
Windows için Firebase CLI'yı aşağıdaki seçeneklerden birini kullanarak yükleyebilirsiniz:
| Seçenek | Açıklama | Şu amaçlar için önerilir: |
|---|---|---|
| bağımsız ikili program | CLI için bağımsız ikili programı indirin. Ardından, firebase komutunu çalıştırabileceğiniz bir kabuk açmak için yürütülebilir dosyaya erişebilirsiniz.
|
Yeni geliştiriciler Node.js kullanmayan veya bu platforma aşina olmayan geliştiriciler |
| npm | KSA'yı yüklemek ve genel olarak kullanılabilen firebase komutunu etkinleştirmek için npm'yi (Node Package Manager) kullanın.
|
Node.js kullanan geliştiriciler |
bağımsız ikili dosya
Firebase KSA'nın ikili programını indirip çalıştırmak için aşağıdaki adımları uygulayın:
firebasekomutunu çalıştırabileceğiniz bir kabuk açmak için ikili dosyaya erişin.Giriş yapıp KSA'yı test etme adımına geçin.
npm
Firebase CLI'yı yüklemek için npm (Node Package Manager) kullanmak istiyorsanız aşağıdaki adımları uygulayın:
nvm-windows (Node Sürüm Yöneticisi) kullanarak Node.js'yi yükleyin. Node.js'yi yüklediğinizde
npmkomut araçları da otomatik olarak yüklenir.Aşağıdaki komutu çalıştırarak Firebase KSA'yı
npmüzerinden yükleyin:npm install -g firebase-tools
Bu komut, genel olarak kullanılabilen
firebasekomutunu etkinleştirir.Giriş yapıp KSA'yı test etme adımına geçin.
macOS veya Linux
macOS veya Linux için Firebase KSA'yı aşağıdaki seçeneklerden birini kullanarak yükleyebilirsiniz:
| Seçenek | Açıklama | Şu amaçlar için önerilir: |
|---|---|---|
| otomatik yükleme komut dosyası | İşletim sisteminizi otomatik olarak algılayan, en son CLI sürümünü indiren ve ardından genel olarak kullanılabilen firebase komutunu etkinleştiren tek bir komut çalıştırın.
|
Yeni geliştiriciler Node.js kullanmayan veya bu platforma aşina olmayan geliştiriciler CI/CD ortamında otomatik dağıtımlar |
| bağımsız ikili program | CLI için bağımsız ikili programı indirin. Ardından, ikili programı iş akışınıza uyacak şekilde yapılandırıp çalıştırabilirsiniz. | KSA kullanılarak tamamen özelleştirilebilen iş akışları |
| npm | KSA'yı yüklemek ve genel olarak kullanılabilen firebase komutunu etkinleştirmek için npm'yi (Node Package Manager) kullanın.
|
Node.js kullanan geliştiriciler |
otomatik yükleme komut dosyası
Otomatik yükleme komut dosyasını kullanarak Firebase KSA'yı yüklemek için aşağıdaki adımları uygulayın:
Aşağıdaki cURL komutunu çalıştırın:
curl -sL https://firebase.tools | bash
Bu komut dosyası, işletim sisteminizi otomatik olarak algılar, en son Firebase CLI sürümünü indirir ve ardından genel olarak kullanılabilen
firebasekomutunu etkinleştirir.Giriş yapıp KSA'yı test etme adımına geçin.
Otomatik yükleme komut dosyasıyla ilgili daha fazla örnek ve ayrıntı için firebase.tools adresindeki komut dosyasının kaynak koduna bakın.
bağımsız ikili dosya
İşletim sisteminize özel Firebase CLI ikili programını indirip çalıştırmak için aşağıdaki adımları uygulayın:
İşletim sisteminiz için Firebase CLI ikili dosyasını indirin: macOS | Linux
(İsteğe bağlı) Genel olarak kullanılabilen
firebasekomutunu ayarlayın.chmod +x ./firebase_toolskomutunu çalıştırarak ikili dosyayı yürütülebilir hale getirin.- İkili programın yolunu PATH'inize ekleyin.
Giriş yapıp KSA'yı test etme adımına geçin.
npm
Firebase CLI'yı yüklemek için npm (Node Package Manager) kullanmak istiyorsanız aşağıdaki adımları uygulayın:
nvm (Node Sürüm Yöneticisi) kullanarak Node.js'yi yükleyin.
Node.js yüklendiğindenpmkomut araçları da otomatik olarak yüklenir.Aşağıdaki komutu çalıştırarak Firebase KSA'yı
npmüzerinden yükleyin:npm install -g firebase-tools
Bu komut, genel olarak kullanılabilen
firebasekomutunu etkinleştirir.Giriş yapıp KSA'yı test etme adımına geçin.
Giriş yapma ve Firebase CLI'yi test etme
CLI'yı yükledikten sonra kimlik doğrulaması yapmanız gerekir. Ardından Firebase projelerinizi listeleyerek kimlik doğrulamasını onaylayabilirsiniz.
Aşağıdaki komutu çalıştırarak Google Hesabınızı kullanarak Firebase'e giriş yapın:
firebase login
Bu komut, yerel makinenizi Firebase'e bağlar ve Firebase projelerinize erişmenizi sağlar.
Firebase projelerinizi listeleyerek CLI'nın doğru şekilde yüklendiğini ve hesabınıza eriştiğini test edin. Aşağıdaki komutu çalıştırın:
firebase projects:list
Görüntülenen liste, Firebase konsolunda listelenen Firebase projeleriyle aynı olmalıdır.
En yeni CLI sürümüne güncelleme
Genellikle en güncel Firebase CLI sürümünü kullanmanız önerilir.
KSA sürümünü nasıl güncelleyeceğiniz, işletim sisteminize ve KSA'yı nasıl yüklediğinize bağlıdır.
Windows
- Bağımsız ikili program: Yeni sürümü indirin, ardından sisteminizde değiştirin.
- npm:
npm install -g firebase-toolskomutunu çalıştırın.
macOS
Otomatik yükleme komut dosyası:
curl -sL https://firebase.tools | upgrade=true bashkomutunu çalıştırın.Bağımsız ikili program: Yeni sürümü indirin ve sisteminizdeki sürümle değiştirin.
npm:
npm install -g firebase-toolskomutunu çalıştırın.
Linux
Otomatik yükleme komut dosyası:
curl -sL https://firebase.tools | upgrade=true bashkomutunu çalıştırın.Bağımsız ikili program: Yeni sürümü indirin ve sisteminizdeki sürümle değiştirin.
npm:
npm install -g firebase-toolskomutunu çalıştırın.
Firebase CLI'yı kaldırma
CLI'yı nasıl kaldıracağınız, işletim sisteminize ve CLI'yı nasıl yüklediğinize bağlıdır.
Windows
- Bağımsız ikili program: İndirdiğiniz
firebase.exeikili programını silin. - npm:
npm uninstall -g firebase-toolskomutunu çalıştırın.
macOS
Otomatik yükleme komut dosyası: Çalıştır
curl -sL https://firebase.tools | uninstall=true bashBağımsız ikili program: İndirdiğiniz
firebaseikili programını silin. KonumunuPATHortam değişkeninize eklediyseniz kaldırdığınızdan emin olun.npm:
npm uninstall -g firebase-toolskomutunu çalıştırın.
Linux
Otomatik yükleme komut dosyası: Çalıştır
curl -sL https://firebase.tools | uninstall=true bashBağımsız ikili program: İndirdiğiniz
firebaseikili programını silin. KonumunuPATHortam değişkeninize eklediyseniz kaldırdığınızdan emin olun.npm:
npm uninstall -g firebase-toolskomutunu çalıştırın.
CLI'yı CI sistemleriyle kullanma
CLI'yı CI sistemleriyle kullanırken Uygulama Varsayılan Kimlik Bilgileri'ni kullanarak kimlik doğrulamanızı öneririz.
(Önerilir) Uygulama Varsayılan Kimlik Bilgileri'ni kullanma
Firebase CLI, ayarlanmışsa Uygulama Varsayılan Kimlik Bilgileri'ni algılar ve kullanır. KSA'nın CI ve diğer gözetimsiz ortamlarda kimliğini doğrulamanın en basit yolu, Uygulama Varsayılan Kimlik Bilgileri'ni ayarlamaktır.
(Eski) Kullanım FIREBASE_TOKEN
Alternatif olarak, FIREBASE_TOKEN kullanarak kimlik doğrulaması yapabilirsiniz. Bu yöntem, Uygulama Varsayılan Kimlik Bilgileri'nden daha az güvenlidir ve artık önerilmemektedir.
Tarayıcısı olan bir makinede Firebase KSA'yı yükleyin.
Aşağıdaki komutu çalıştırarak oturum açma işlemini başlatın:
firebase login:ci
Sağlanan URL'yi ziyaret edin ve bir Google Hesabı kullanarak giriş yapın.
Yeni bir yenileme jetonu yazdırın. Mevcut CLI oturumu bu durumdan etkilenmez.
Çıkış jetonunu CI sisteminizde güvenli ancak erişilebilir bir şekilde saklayın.
firebasekomutlarını çalıştırırken bu jetonu kullanın. Aşağıdaki iki seçenekten birini kullanabilirsiniz:1. seçenek: Jetonu ortam değişkeni olarak depolama
FIREBASE_TOKEN. Sisteminiz jetonu otomatik olarak kullanır.2. seçenek: CI sisteminizde tüm
firebasekomutlarını--token TOKENişaretiyle çalıştırın.
Jeton yükleme için öncelik sırası şu şekildedir: işaret, ortam değişkeni, istenen Firebase projesi.
Firebase projesi başlatma
CLI kullanılarak gerçekleştirilen birçok yaygın görev (ör. bir Firebase projesine dağıtım yapma) için proje dizini gerekir. firebase init komutunu kullanarak bir proje dizini oluşturun. Proje dizini genellikle kaynak denetimi kök dizininizle aynıdır ve firebase init komutunu çalıştırdıktan sonra dizinde bir firebase.json yapılandırma dosyası bulunur.
Yeni bir Firebase projesi başlatmak için uygulamanızın dizininde aşağıdaki komutu çalıştırın:
firebase init
firebase init komutu, proje dizininizi ve bazı Firebase ürünlerini ayarlama adımlarında size yol gösterir. Proje başlatma sırasında Firebase CLI, aşağıdaki görevleri tamamlamanızı ister:
Varsayılan bir Firebase projesi seçin.
Bu adım, mevcut proje dizinini bir Firebase projesiyle ilişkilendirir. Böylece projeye özel komutlar (ör.
firebase deploy) uygun Firebase projesinde çalıştırılır.Ayrıca, aynı proje diziniyle birden fazla Firebase projesini ilişkilendirmek (ör. hazırlık projesi ve üretim projesi) de mümkündür.
Firebase projenizde ayarlamak istediğiniz Firebase ürünlerini seçin.
Bu adımda, seçilen ürünler veya özellikler için belirli dosyaların yapılandırmalarını ayarlamanız istenir. Bu yapılandırmalar hakkında daha fazla bilgi için ilgili ürünün belgelerine (ör. Hosting veya Authentication) bakın. Daha fazla Firebase ürünü ayarlamak için
firebase initkomutunu daha sonra da çalıştırabilirsiniz.
İlk kullanıma hazırlama işleminin sonunda Firebase, yerel uygulama dizininizin kökünde otomatik olarak aşağıdaki iki dosyayı oluşturur:
Proje yapılandırmanızı listeleyen bir
firebase.jsonyapılandırma dosyası.Projenizin takma adlarını depolayan bir
.firebasercdosyası.
firebase.json dosyası
firebase init komutu, proje dizininizin kökünde bir firebase.json yapılandırma dosyası oluşturur.
firebase.json dosyası, öğeleri Firebase CLI ile dağıtmak için gereklidir. Bu dosya, proje dizininizdeki hangi dosyaların ve ayarların Firebase projenize dağıtılacağını belirtir (ör. Hosting ayarları, Authentication sağlayıcı yapılandırmaları, güvenlik kuralları ve Cloud Functions yapılandırması).
Bazı ayarlar proje dizininizde veya Firebase konsolunda tanımlanabildiğinden olası dağıtım çakışmalarını çözdüğünüzden emin olun.
Firebase Hosting seçeneklerinin çoğunu
doğrudan firebase.json dosyasında yapılandırabilirsiniz. Ancak Firebase CLI ile dağıtılabilen diğer Firebase hizmetleri için firebase init komutu, bu hizmetlerin ayarlarını tanımlayabileceğiniz belirli dosyalar oluşturur (ör. Cloud Functions için index.js dosyası). Ayrıca firebase.json dosyasında dağıtım öncesi veya dağıtım sonrası kancalar da ayarlayabilirsiniz.
Aşağıdaki firebase.json dosyası, birçok Firebase hizmetinin yapılandırma seçeneklerini gösteren kapsamlı bir örnektir. Ayrıca çoklu kod tabanı Cloud Functions, Local Emulator Suite kurulumu ve Remote Config şablonu gibi özellikleri de gösterir. Belirli bir proje için firebase.json dosyasının yalnızca o projeye yönelik olarak ayarlanmış Firebase hizmetlerinin yapılandırmalarını (ör. yalnızca Firebase Hosting ve Cloud Functions) içereceğini unutmayın. $schema anahtarının eklenmesi, birçok kod düzenleyicide doğrulama ve otomatik tamamlama özelliklerini etkinleştirir.
{
"$schema": "https://raw.githubusercontent.com/firebase/firebase-tools/master/schema/firebase-config.json",
"hosting": {
"public": "public",
"ignore": [
"firebase.json",
"**/.*",
"**/node_modules/**"
],
"cleanUrls": true,
"trailingSlash": false
},
"apphosting": {
"backendId": "my-app",
"rootDir": "backend",
"ignore": [
"firebase.json",
"**/.*",
"**/node_modules/**"
]
},
"firestore": {
"rules": "firestore.rules",
"indexes": "firestore.indexes.json"
},
"storage": {
"rules": "storage.rules"
},
"database": {
"rules": "database.rules.json"
},
"dataconnect": {
"source": "dataconnect",
"location": "us-central1"
},
"functions": [
{
"source": "functions",
"codebase": "default",
"ignore": [
"**/.*",
"**/node_modules/**"
],
"predeploy": [
"npm --prefix \"$RESOURCE_DIR\" run lint",
"npm --prefix \"$RESOURCE_DIR\" run build"
]
}
],
"emulators": {
"auth": {
"port": 9099
},
"functions": {
"port": 5001
},
"firestore": {
"port": 8080
},
"hosting": {
"port": 5000
},
"storage": {
"port": 9199
},
"ui": {
"enabled": true,
"port": 4000
},
"singleProjectMode": true
},
"extensions": {
"my-storage-resizer": "firebase/storage-resize-images@^0.1.0"
},
"auth": {
"providers": {
"anonymous": true,
"emailPassword": true,
"googleSignIn": {
"oAuthBrandDisplayName": "My App",
"supportEmail": "support@myapp.com"
}
}
},
"remoteconfig": {
"template": "remoteconfig.template.json"
}
}
Varsayılan olarak firebase.json kullanılsa da alternatif bir yapılandırma dosyası belirtmek için --config PATH işaretini iletebilirsiniz.
Birden fazla Cloud Firestore veritabanı için yapılandırma
firebase init komutunu çalıştırdığınızda firebase.json dosyanız, yukarıdaki örnekte gösterildiği gibi projenizin varsayılan veritabanına karşılık gelen tek bir firestore anahtarı içerir.
Projenizde birden fazla Cloud Firestore veritabanı varsa firebase.json dosyanızı düzenleyerek her veritabanıyla farklı Cloud Firestore Security Rules ve veritabanı dizini kaynak dosyalarını ilişkilendirin. Dosyayı, her veritabanı için bir giriş içeren bir JSON dizisiyle değiştirin.
"firestore": [
{
"database": "(default)",
"rules": "firestore.default.rules",
"indexes": "firestore.default.indexes.json"
},
{
"database": "ecommerce",
"rules": "firestore.ecommerce.rules",
"indexes": "firestore.ecommerce.indexes.json"
}
],
Dağıtımda yoksayılacak Cloud Functions dosya
İşlev dağıtımı sırasında KSA, functions dizininde yoksayılacak dosyaların listesini otomatik olarak belirtir. Bu sayede, dağıtımınızın veri boyutunu artırabilecek gereksiz dosyaların arka uca dağıtılması önlenir.
Varsayılan olarak yoksayılan dosyaların JSON biçiminde gösterilen listesi şöyledir:
"ignore": [
".git",
".runtimeconfig.json",
"firebase-debug.log",
"firebase-debug.*.log",
"node_modules"
]
firebase.json içinde ignore için kendi özel değerlerinizi eklerseniz yukarıdaki listede gösterilen dosya listesini sakladığınızdan (veya eksikse eklediğinizden) emin olun.
Proje takma adlarını yönetme
Birden fazla Firebase projesini aynı proje diziniyle ilişkilendirebilirsiniz.
Örneğin, hazırlık için bir Firebase projesi, üretim için başka bir Firebase projesi kullanmak isteyebilirsiniz. Farklı proje ortamları kullanarak değişiklikleri üretime dağıtmadan önce doğrulayabilirsiniz. firebase use komutu, takma adlar arasında geçiş yapmanıza ve yeni takma adlar oluşturmanıza olanak tanır.
Proje takma adı ekleme
Proje başlatma sırasında bir Firebase projesi seçtiğinizde projeye otomatik olarak default takma adı atanır. Ancak projeye özel komutların farklı bir Firebase projesinde çalıştırılmasına izin vermek ve aynı proje dizinini kullanmaya devam etmek için proje dizininizden aşağıdaki komutu çalıştırın:
firebase use --add
Bu komut, başka bir Firebase projesi seçmenizi ve projeyi takma ad olarak atamanızı ister. Takma ad atamaları, proje dizininizdeki bir .firebaserc dosyasına yazılır.
Proje takma adlarını kullanma
Atanan Firebase projesi takma adlarını kullanmak için proje dizininizden aşağıdaki komutlardan birini çalıştırın.
| Komut | Açıklama |
|---|---|
firebase use |
Proje dizininiz için tanımlanmış takma adların listesini görüntüleme |
firebase use \ |
Tüm komutları, belirtilen Firebase projesinde çalıştırılacak şekilde yönlendirir.
CLI, bu projeyi "etkin proje" olarak kullanır. |
firebase use --clear |
Etkin projeyi temizler.
Diğer CLI komutlarını çalıştırmadan önce yeni bir etkin proje ayarlamak için |
firebase use \ |
Proje dizininizden bir takma adı kaldırır. |
Herhangi bir CLI komutuyla --project işaretini ileterek etkin proje olarak kullanılan projeyi geçersiz kılabilirsiniz. Örneğin: CLI'nızı, staging takma adını atadığınız bir Firebase projesinde çalışacak şekilde ayarlayabilirsiniz. prod takma adını atadığınız Firebase projesinde tek bir komut çalıştırmak istiyorsanız örneğin komutunu çalıştırabilirsiniz.
Kaynak denetimi ve proje takma adları
Genel olarak, ekibinizin proje takma adlarını paylaşmasına izin vermek için .firebaserc dosyanızı kaynak denetimine eklemeniz gerekir. Ancak açık kaynak projeler veya başlangıç şablonları için genellikle .firebaserc dosyanızı eklememelisiniz.
Yalnızca sizin kullanımınıza yönelik bir geliştirme projeniz varsa her komutla birlikte --project işaretini iletebilir veya Firebase projesine takma ad atamadan firebase use PROJECT_ID komutunu çalıştırabilirsiniz.
Firebase projenizi yerel olarak sunma ve test etme
Firebase projenizi üretime dağıtmadan önce yerel olarak barındırılan URL'lerde görüntüleyebilir ve test edebilirsiniz. Yalnızca belirli özellikleri test etmek istiyorsanız firebase serve komutundaki bir işaretçide virgülle ayrılmış liste kullanabilirsiniz.
Aşağıdaki görevlerden birini yapmak istiyorsanız yerel proje dizininizin kökünden aşağıdaki komutu çalıştırın:
- Firebase'de barındırılan uygulamanızın statik içeriğini görüntüleme
- Firebase Hosting için dinamik içerik oluşturmak amacıyla Cloud Functions kullanıyorsanız ve yerel bir URL'de Hosting emülasyonu yapmak için üretim (dağıtılmış) HTTP işlevlerinizi kullanmak istiyorsanız.
firebase serve --only hosting
Yerel HTTP işlevlerini kullanarak projenizin emülasyonunu oluşturma
Yerel HTTP işlevlerini kullanarak projenizin emülasyonunu oluşturmak için proje dizininizden aşağıdaki komutlardan birini çalıştırın.
HTTP işlevlerini ve barındırmayı yerel URL'lerde test etmek için aşağıdaki komutlardan birini kullanın:
firebase serve
firebase serve --only functions,hosting // uses a flag
Yalnızca HTTP işlevlerini emüle etmek için aşağıdaki komutu kullanın:
firebase serve --only functions
Diğer yerel cihazlardan test etme
Varsayılan olarak firebase serve, yalnızca localhost tarafından gönderilen isteklere yanıt verir. Bu, barındırılan içeriğinize bilgisayarınızın web tarayıcısından erişebileceğiniz ancak ağınızdaki diğer cihazlardan erişemeyeceğiniz anlamına gelir. Diğer yerel cihazlardan test etmek istiyorsanız --host işaretini şu şekilde kullanın:
firebase serve --host 0.0.0.0 // accepts requests to any host
Firebase projesine dağıtma
Firebase CLI, kod ve öğelerin Firebase projenize dağıtımını yönetir. Bu öğeler arasında şunlar bulunur:
- Firebase Hosting sitenizin yeni sürümleri
- Yeni, güncellenmiş veya mevcut Cloud Functions for Firebase
- Firebase SQL Connect için yeni veya güncellenmiş şemalar ve bağlayıcılar
- Firebase Realtime Database için Security Rules
- Cloud Storage for Firebase için Security Rules
- Cloud Firestore için Security Rules
- Cloud Firestore için dizinler
- Authentication için yapılandırma
Bir Firebase projesine dağıtım yapmak için proje dizininizden aşağıdaki komutu çalıştırın:
firebase deploy
İsterseniz dağıtımlarınızın her birine yorum ekleyebilirsiniz. Bu yorum, projenizin Firebase Hosting sayfasındaki diğer dağıtım bilgileriyle birlikte gösterilir. Örneğin:
firebase deploy -m "Deploying the best new feature ever."
firebase deploy komutunu kullanırken aşağıdakileri göz önünde bulundurun:
Kaynakları bir proje dizininden dağıtmak için proje dizininde bir
firebase.jsondosyası olmalıdır. Bu dosya,firebase initkomutu tarafından sizin için otomatik olarak oluşturulur.Varsayılan olarak
firebase deploy, proje dizininizdeki tüm dağıtılabilir kaynaklar için bir sürüm oluşturur. Belirli Firebase hizmetlerini veya özelliklerini dağıtmak için kısmi dağıtımı kullanın.
Belirli Firebase hizmetlerini dağıtma
Yalnızca belirli Firebase hizmetlerini veya özelliklerini dağıtmak istiyorsanız firebase deploy komutundaki bir işaretçide virgülle ayrılmış liste kullanabilirsiniz. Örneğin, aşağıdaki komut Firebase Hosting içeriğini ve Cloud Storage Security Rules dağıtır.
firebase deploy --only hosting,storage
Aşağıdaki tabloda, kısmi dağıtım için kullanılabilen hizmetler ve özellikler listelenmiştir. İşaretlerdeki adlar, firebase.json yapılandırma dosyanızdaki anahtarlara karşılık gelir.
| İşaret söz dizimi | Dağıtılan hizmet veya özellik |
|---|---|
--only auth |
Authentication sağlayıcı yapılandırması |
--only database |
Firebase Realtime Database Security Rules |
--only dataconnect |
Firebase SQL Connect şema ve bağlayıcı |
--only firestore |
Yapılandırılmış tüm veritabanları için Cloud Firestore Security Rules ve dizinler |
--only functions |
Cloud Functions for Firebase |
--only hosting |
Firebase Hosting içerik |
--only storage |
Cloud Storage for Firebase Security Rules |
Security Rules için dağıtım çakışmaları
Firebase Realtime Database, Cloud Storage for Firebase ve Cloud Firestore için Security Rules değişkenini yerel proje dizininizde veya Firebase konsolunda tanımlayabilirsiniz.
Dağıtım çakışmalarını önlemenin bir başka yolu da kısmi dağıtım kullanmak ve Firebase konsolunda yalnızca Security Rules tanımlamaktır.
Dağıtım öncesi ve dağıtım sonrası komut dosyası görevlerini ayarlama
Dağıtım öncesi veya dağıtım sonrası görevleri gerçekleştirmek için kabuk komut dosyalarını firebase deploy komutuna bağlayabilirsiniz. Örneğin, dağıtım öncesi komut dosyası, TypeScript kodunu JavaScript'e çevirebilir ve dağıtım sonrası kancası, yöneticileri Firebase Hosting adresine yapılan yeni site içeriği dağıtımları hakkında bilgilendirebilir.
Dağıtım öncesi veya dağıtım sonrası kancaları ayarlamak için firebase.json yapılandırma dosyanıza bash komut dosyaları ekleyin. Kısa komut dosyalarını doğrudan firebase.json dosyasında tanımlayabilir veya proje dizininizdeki diğer dosyalara başvurabilirsiniz.
Örneğin, aşağıdaki komut dosyası, Firebase Hosting ortamına başarılı bir şekilde dağıtım yapıldığında Slack mesajı gönderen bir dağıtım sonrası görevin firebase.json ifadesidir.
"hosting": {
// ...
"postdeploy": "./messageSlack.sh 'Just deployed to Firebase Hosting'",
"public": "public"
}
messageSlack.sh komut dosyası, proje dizininde bulunur ve şu şekilde görünür:
curl -X POST -H 'Content-type: application/json' --data '{"text":"$1"}'
\https://SLACK_WEBHOOK_URLDağıtabileceğiniz tüm öğeler için predeploy ve postdeploy kancaları oluşturabilirsiniz. firebase deploy komutunu çalıştırmanın, firebase.json dosyanızda tanımlanan tüm dağıtım öncesi ve dağıtım sonrası görevleri tetiklediğini unutmayın. Yalnızca belirli bir Firebase hizmetiyle ilişkili görevleri çalıştırmak için kısmi dağıtım komutlarını kullanın.
Hem predeploy hem de postdeploy kancaları, komut dosyalarının standart çıkış ve hata akışlarını terminale yazdırır. Başarısızlık durumları için aşağıdakileri göz önünde bulundurun:
- Dağıtım öncesi kanca beklendiği gibi tamamlanamazsa dağıtım iptal edilir.
- Dağıtım herhangi bir nedenle başarısız olursa dağıtım sonrası kancalar tetiklenmez.
Ortam değişkenleri
Dağıtım öncesi ve dağıtım sonrası kancalarında çalışan komut dosyalarında aşağıdaki ortam değişkenleri kullanılabilir:
$GCLOUD_PROJECT: Etkin projenin proje kimliği$PROJECT_DIR:firebase.jsondosyasını içeren kök dizin$RESOURCE_DIR: (Yalnızcahostingvefunctionskomut dosyaları için) Dağıtılacak Hosting veya Cloud Functions kaynaklarını içeren dizinin konumu
Dağıtım kotaları
Firebase dağıtım işlemlerinizin hızını veya hacmini sınırlayan bir kotayı aşmanız mümkündür (ancak bu pek olası değildir). Örneğin, çok sayıda işlev dağıtırken HTTP 429 Quota hata mesajı alabilirsiniz. Bu tür sorunları çözmek için kısmi dağıtımı kullanmayı deneyin.
Dağıtımı geri alma
Seçilen sürüm için Geri alma işlemini seçerek projenizin Firebase Hosting sayfasından Firebase Hosting dağıtımını geri alabilirsiniz.
Firebase Realtime Database, Cloud Storage for Firebase veya Cloud Firestore için Security Rules sürümlerini geri almak mümkün değildir.
Komut referansı
Bu bölümde, aşağıdaki kullanım alanları ve ürünler için kullanılabilen komutlar açıklanmaktadır:
- KSA yönetim komutları
- Proje yönetimi komutları
- Dağıtım ve yerel geliştirme
- App Distribution komutları
- App Hosting komutları
- Authentication (kullanıcı yönetimi) komutları
- Cloud Firestore komutları
- Cloud Functions for Firebase komutları
- Crashlytics komutları
- Extensions komutları
- Extensions yayıncı komutları
- Hosting komutları
- Realtime Database komutları
- Remote Config komutları
- SQL Connect komutları
CLI yönetim komutları
| Komut | Açıklama |
|---|---|
help
|
CLI veya belirli komutlar hakkında yardım bilgilerini gösterir. |
init
|
Mevcut dizinde yeni bir Firebase projesi ilişkilendirin ve oluşturun.
Bu komut, geçerli dizinde bir firebase.json yapılandırma dosyası oluşturur.
|
login
|
CLI'nın kimliğini Google Hesabınızla doğrulayın. Web tarayıcısına erişim gerekir.
|
login:ci
|
Kullanımdan kaldırıldı.
Bunun yerine, Google Cloud hizmet hesabı (GOOGLE_APPLICATION_CREDENTIALS) ile Uygulama Varsayılan Kimlik Bilgileri'ni kullanın.
Etkileşimli olmayan ortamlarda kullanılacak bir kimlik doğrulama jetonu oluşturun. |
login:add
|
Ek bir Google Hesabı'na giriş yapın. |
login:list
|
Kimliği doğrulanmış tüm Google Hesaplarını listeleme |
login:use \
|
Etkin Google Hesabı'nı ayarlayın. |
logout
|
CLI'da Google Hesabınızın oturumunu kapatın. |
open
|
İlgili proje kaynaklarına erişmek için bir tarayıcı açın. |
projects:list
|
Erişiminiz olan tüm Firebase projelerini listeler. |
use
|
CLI için etkin Firebase projesini ayarlayın. Proje takma adlarını yönetme hakkında daha fazla bilgi edinin. |
Proje yönetimi komutları
| Komut | Açıklama |
|---|---|
| Firebase projelerinin yönetimi | |
projects:addfirebase
|
Mevcut bir Google Cloud projesine Firebase'e özgü yapılandırmalar ekleyin ve Firebase'e özgü hizmetleri etkinleştirin. |
projects:create
|
Yeni bir Google Cloud projesi oluşturun, ardından Firebase'e özel yapılandırmaları ekleyin ve yeni projede Firebase'e özel hizmetleri etkinleştirin. |
projects:list
|
Erişiminiz olan tüm Firebase projelerini listeler. |
| Firebase uygulamalarının yönetimi (iOS, Android, web) | |
apps:create
|
Yeni bir Firebase uygulaması oluşturun. |
apps:list
|
Etkin Firebase projesindeki tüm kayıtlı Firebase uygulamalarını listeler. |
apps:sdkconfig \
|
Belirtilen Firebase uygulamasının Firebase yapılandırmasını yazdırır.
KSA, etkileşimli olmayan modda çalışıyorsa:
Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
| SHA sertifika karmalarının yönetimi (yalnızca Android) | |
apps:android:sha:create \
|
Belirtilen SHA sertifika karmasını belirtilen Firebase Android uygulamasına ekler. |
apps:android:sha:delete \
|
Belirtilen Firebase Android uygulamasından, belirtilen SHA sertifikasını (apps:android:sha:list içindeki SHA_ID ile tanımlanır) silin.
|
apps:android:sha:list \
|
Belirtilen Firebase Android uygulaması için tüm SHA sertifika karmalarını listeler. |
Dağıtım ve yerel geliştirme
Bu komutlar, Firebase projenizi dağıtmanıza ve projenizle etkileşim kurmanıza olanak tanır.
| Komut | Açıklama |
|---|---|
deploy
|
Proje dizininizdeki kodları ve öğeleri etkin Firebase projesine dağıtın.
Bu komut, proje dizininizde bir Firebase projesine dağıtım yapma hakkında daha fazla bilgi edinin. |
serve
|
Firebase Hosting yapılandırmanızı ve/veya yerel HTTP Cloud Functions (örneğin,
Bu komut, proje dizininizde bir Yerel olarak yayınlama ve test etme hakkında daha fazla bilgi edinin. |
App Distribution komut
| Komut | Açıklama |
|---|---|
appdistribution:distribute \
|
Belirtilen sürüm ikili program dosyasını (.apk, .aab veya .ipa) yükleyin ve belirtilen Firebase uygulaması için test kullanıcılarının kullanımına sunun.
|
appdistribution:testers:add \
|
Etkin Firebase projesine bir veya daha fazla test kullanıcısı (boşlukla ayrılmış EMAILS olarak belirtilir) ekleyin. EMAILS
atlanırsa Bu komut yalnızca projede henüz yer almayan test kullanıcılarını ekler; mevcut test kullanıcılarını kaldırmaz veya üzerine yazmaz. Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
|
appdistribution:testers:remove \
|
Test kullanıcılarını (boşlukla ayrılmış EMAILS olarak belirtilir) etkin Firebase projesinden kaldırın. EMAILS atlanırsa Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
|
appdistribution:testers:list
|
Etkin Firebase projesindeki test kullanıcılarını listeler. |
appdistribution:groups:create \
|
Belirtilen DISPLAY_NAME ve isteğe bağlı GROUP_ALIAS ile bir test kullanıcısı grubu oluşturun.
GROUP_ALIAS atlanırsa DISPLAY_NAME üzerinden otomatik olarak bir takma ad oluşturulur. |
appdistribution:groups:delete \
|
Belirtilen takma ada sahip test kullanıcısı grubunu siler. |
appdistribution:groups:list
|
Etkin Firebase projesindeki tüm test kullanıcısı gruplarını listeler. |
App Hosting komut
| Komut | Açıklama |
|---|---|
apphosting:backends:create \
|
App Hosting arka ucu içeren tek bir kod tabanına bağlı yönetilen kaynaklar koleksiyonunu oluşturun. Bu komut, aşağıdaki isteğe bağlı (ancak önerilen) işaretleri destekler:
Bu komut, aşağıdaki isteğe bağlı işaretleri de destekler:
CLI etkileşimli olmayan modda çalışıyorsa hem |
apphosting:backends:get \
|
Belirtilen App Hosting arka ucunun herkese açık URL dahil ayrıntılarını alın.
Birden fazla bölge belirtilen BACKEND_ID ile bir arka uç içeriyorsa CLI bir uyarı kaydeder ve eşleşen ilk arka ucu yazdırır (bu komutun |
apphosting:backends:list
|
Etkin Firebase projesindeki tüm etkin App Hosting arka uçlarını listeler. |
apphosting:backends:delete \
|
Belirtilen App Hosting arka ucunu silin.
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin:
Birden fazla bölge belirtilen BACKEND_ID değerine sahip bir arka uç içeriyorsa CLI, etkileşimli modda hangi arka uçların silineceğini seçmenizi ister ve |
apphosting:rollouts:create \
|
Belirtilen App Hosting arka ucu için manuel olarak tetiklenen bir sunum oluşturun. Bu komut, aşağıdaki isteğe bağlı, birbirini dışlayan işaretleri destekler. Hiçbiri sağlanmazsa CLI, dallar listesinden seçim yapmanızı ister. Etkileşimli olmayan modda bu işaretlerden birinin sağlanması gerekir.
Birden fazla bölge, belirtilen BACKEND_ID değerine sahip bir arka uç içeriyorsa bu komut hem etkileşimli hem de etkileşimli olmayan modlarda başarısız olur (Bu komutun |
apphosting:secrets:set \
|
Belirtilen SECRET_NAME ile Google Cloud Secret Manager içinde gizli anahtar oluşturun veya mevcut bir gizli anahtarı güncelleyin. Bu komut, aşağıdaki isteğe bağlı (ancak önerilen) işareti destekler:
Bu komut, aşağıdaki isteğe bağlı işareti de destekler:
CLI etkileşimli olmayan modda çalışıyorsa |
apphosting:secrets:grantaccess \
|
Belirtilen gizli anahtarlar için bir dizi kullanıcı veya grup e-posta adresine ya da bir arka uç hizmet hesabına izin verin. Ardından, derleme veya çalışma zamanında App Hosting tarafından gizli anahtarlara erişilebilir.
Virgülle ayrılmış bir veya daha fazla SECRET_NAME değeri iletebilirsiniz. Bir dizi kullanıcı veya grup e-posta adresine erişim izni verme:
Bir arka ucun hizmet hesabına erişim izni verme:
|
apphosting:secrets:revokeaccess \
|
Belirtilen gizli anahtarlara erişim izinlerini bir dizi kullanıcı veya grup e-postasından ya da bir arka uç hizmet hesabından iptal edin.
Virgülle ayrılmış bir veya daha fazla SECRET_NAME değeri iletebilirsiniz. Bir grup kullanıcı veya grup e-posta adresinin erişimini iptal etme:
Arka uç hizmet hesabının erişimini iptal etme:
|
apphosting:secrets:describe \
|
Belirtilen gizli anahtar adı için meta verileri ve sürümleri alın. |
apphosting:secrets:access \
|
Belirtilen sürümde, belirtilen gizli anahtar adı için gizli anahtarın değerine erişin.
[@VERSION] atlanırsa varsayılan olarak en yeni sürüme erişilir.
|
Authentication (kullanıcı yönetimi) komutları
| Komut | Açıklama |
|---|---|
auth:export \
|
Etkin Firebase projesinin kullanıcı hesaplarını bir JSON veya CSV dosyasına aktarın. Daha fazla bilgi için "auth:import and auth:export" sayfasına bakın. |
auth:import \
|
Kullanıcı hesaplarını bir JSON veya CSV dosyasından etkin Firebase projesine aktarın. Daha fazla bilgi için "auth:import and auth:export" sayfasını inceleyin. |
Cloud Firestore komut
| Komut | Açıklama |
|---|---|
firestore:locations
|
Etkin Firebase projesindeki Cloud Firestore veritabanı örnekleri için kullanılabilir konumları listeler. Standard sürüm, Enterprise sürüm ve MongoDB uyumluluğu için kullanılabilir konumlar hakkında bilgi edinin. |
firestore:databases:create \
|
Belirtilen konumda belirtilen Cloud Firestore veritabanı örneğini (yerel modda) oluşturun.
Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
|
firestore:databases:list |
Etkin Firebase projesindeki tüm Cloud Firestore veritabanı örneklerini listeler. |
firestore:databases:get \
|
Belirtilen Cloud Firestore veritabanı örneğinin veritabanı yapılandırmasını alın.
Tablo çıkışı, tüm veritabanları için veritabanının |
firestore:databases:update \
|
Belirtilen Cloud Firestore veritabanı örneğinin veritabanı yapılandırmasını güncelleyin. En az bir işaret gereklidir (atlanmış işaretler mevcut ayarlarını korur). Bu komut aşağıdaki işaretleri destekler:
|
firestore:databases:delete \
|
Belirtilen Cloud Firestore veritabanı örneğini silin.
CLI, işlem yapmadan önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli olmayan modda gereklidir) |
firestore:indexes
|
Bir Cloud Firestore veritabanı örneğinin tüm dizinlerini listeleme Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
firestore:delete \
|
Belirtilen veritabanı yolundaki (PATH) dokümanları bir Cloud Firestore veritabanı örneğinden silin.
CLI kullanarak Cloud Firestore verilerini silmenin okuma ve silme maliyetlerine yol açacağını unutmayın. Daha fazla bilgi için Cloud Firestore faturalandırmasını anlama başlıklı makaleyi inceleyin. Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin: |
Cloud Functions for Firebase komut
Daha fazla bilgi için ortam yapılandırma belgelerine bakın.
| Komut | Açıklama |
|---|---|
functions:config:export
|
Etkin Firebase projesinin eski Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
|
functions:delete \
|
Etkin Firebase projesinden belirtilen bir veya daha fazla işlevi siler.
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin: |
functions:list
|
Etkin Firebase projesinde dağıtılan tüm işlevleri listeler. |
functions:log
|
Etkin Firebase projesinde dağıtılan tüm Cloud Functions için günlükleri okuyun. |
functions:secrets:access \
|
Belirtilen sürümde, belirtilen gizli anahtar adı için gizli anahtarın değerine erişin.
[@VERSION] atlanırsa varsayılan olarak en yeni sürüme erişilir.
|
functions:secrets:destroy \
|
Belirtilen sürümdeki belirtilen gizli anahtarı siler.
CLI, işlem yapmadan önce bir onay istemi gösterir. Bu istem, |
functions:secrets:get \
|
Belirtilen gizli anahtar adı için meta verileri ve sürümleri alın. |
functions:secrets:prune
|
Etkin Firebase projesindeki kullanılmayan tüm gizli anahtarları imha edin. |
functions:secrets:set \
|
Belirtilen gizli anahtarı oluşturun veya güncelleyin. |
functions:shell
|
İşlevleri test etmek için yerel bir etkileşimli kabuk başlatın. |
functions:config:clone \
|
Kullanımdan kaldırıldı.
Varsayılan olarak devre dışıdır. Bu komutu kullanmak için önce |
functions:config:get
|
Kullanımdan kaldırıldı.
Etkin Firebase projesinin Cloud Functions mevcut yapılandırma değerlerini alın. |
functions:config:set \
|
Kullanımdan kaldırıldı.
Varsayılan olarak devre dışıdır. Bu komutu kullanmak için önce |
functions:config:unset \
|
Kullanımdan kaldırıldı.
Varsayılan olarak devre dışıdır. Bu komutu kullanmak için önce |
Crashlytics komut
| Komut | Açıklama |
|---|---|
crashlytics:mappingfile:generateid \
|
Belirtilen Android kaynak (XML) dosyasında benzersiz bir eşleme dosyası kimliği oluşturun. |
crashlytics:mappingfile:upload \
|
Belirtilen Firebase uygulaması için Proguard uyumlu bir eşleme (TXT) dosyası yükleyin ve bu dosyayı, belirtilen Android kaynak (XML) dosyasında bildirilen eşleme dosyası kimliğiyle ilişkilendirin. |
crashlytics:symbols:upload \
|
Android yerel kitaplık kilitlenmeleri (ör. Android NDK veya Unity ya da Flutter'ın Android derlemeleri) için Crashlytics ile uyumlu bir sembol dosyası oluşturun ve Firebase sunucularına yükleyin.
Bu komut yalnızca Android'i destekler. iOS dSYM'leri için Apple SDK'sının |
Extensions komut
| Komut | Açıklama |
|---|---|
ext
|
Firebase Extensions komutlarının nasıl kullanılacağıyla ilgili bilgileri gösterir.
Etkin projede yüklü uzantı örneklerini listeleme |
ext:configure \
|
Uzantı manifestinizde bir uzantı örneğinin parametre değerlerini yeniden yapılandırın. |
ext:info \
|
Bir uzantıyla ilgili ayrıntılı bilgileri yazdırır. |
ext:install \
|
Uzantı manifestinize yeni bir uzantı örneği ekleyin. |
ext:sdk:install \
|
İşlevlerde uzantıları tanımlamak için SDK'ları yükleyin. |
ext:list
|
Bir Firebase projesinde yüklü olan tüm uzantı örneklerini listeleme
Her uzantının örnek kimliğini yazdırın. |
ext:uninstall \
|
Uzantı manifestinizden bir uzantı örneğini kaldırın. |
ext:update \
|
Bir uzantı örneğini, uzantı manifestinizdeki en yeni sürüme (veya belirtilen yayınlanmış UPDATE_SOURCE sürümüne) güncelleyin. UPDATE_SOURCE için yerel yolların ve URL'lerin desteklenmediğini unutmayın.
CLI, harekete geçmeden önce bir onay istemi gösterir. Etkileşimli modda bu istemi atlamak için |
ext:export
|
Yüklü tüm uzantı örneklerini projenizden uzantı manifestinize aktarın. |
Extensions yayıncı komutu
| Komut | Açıklama |
|---|---|
ext:dev:init
|
Geçerli dizinde yeni bir uzantı için iskelet kod tabanı başlatın. |
ext:dev:list \
|
Bir yayıncı tarafından yüklenen tüm uzantıların listesini yazdırma. |
ext:dev:register
|
Devre dışı.
Yeni yayıncı profili kimliklerinin kaydedilmesi artık desteklenmiyor. |
ext:dev:deprecate \
|
Sürüm yüklemiyle eşleşen uzantı sürümlerini kullanımdan kaldırın.
Sürüm yüklemi tek bir sürüm (ör. 1.0.0) veya bir sürüm aralığı (ör. >1.0.0) olabilir.
Sürüm yüklemi sağlanmazsa ilgili uzantının tüm sürümleri kullanımdan kaldırılır. |
ext:dev:undeprecate \
|
Sürüm yüklemiyle eşleşen uzantı sürümlerini eski haline getirin.
Sürüm yüklemi, tek bir sürüm (ör. 1.0.0) veya bir sürüm aralığı (ör. >1.0.0) olabilir.
|
ext:dev:upload \
|
Uzantının yeni bir sürümünü yükleyin. |
ext:dev:usage \
|
Bir yayıncı tarafından yüklenen uzantıların yükleme sayılarını ve kullanım metriklerini gösterir. |
Hosting komut
| Komut | Açıklama |
|---|---|
hosting:disable
|
Hosting sitesi için Firebase Hosting trafiği sunmayı durdurun. Bu komut çalıştırıldıktan sonra sitenin Hosting URL'sinde "Site Bulunamadı" mesajı gösterilir. Bu komut, aşağıdaki isteğe bağlı işareti destekler:
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin: |
| Hosting sitenin yönetimi | |
hosting:sites:create \
|
Belirtilen SITE_ID değerini kullanarak yeni bir Hosting sitesi oluşturun. CLI etkileşimli olmayan modda çalışıyorsa SITE_ID gereklidir. Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
hosting:sites:delete \
|
Belirtilen Hosting sitesini silin.
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin: |
hosting:sites:get \
|
Belirtilen Hosting sitesiyle ilgili ayrıntıları alın.
Tablo çıkışı; site kimliğini, varsayılan URL'yi ve Firebase web uygulaması kimliğini (bağlıysa) içerir. Ek meta veriler (ör. sitenin |
hosting:sites:list
|
Etkin Firebase projesindeki tüm Hosting sitelerini listeler. |
| Önizleme kanallarının yönetimi | |
hosting:channel:create \
|
Belirtilen CHANNEL_ID kullanarak bir Hosting sitesi için yeni bir önizleme kanalı oluşturun.
CLI etkileşimli olmayan modda çalışıyorsa CHANNEL_ID gereklidir. Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
hosting:channel:delete \
|
Belirtilen önizleme kanalını siler. Bir sitenin canlı kanalını silemezsiniz. Bu komut, aşağıdaki isteğe bağlı işareti destekler:
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin: |
hosting:channel:deploy \
|
Hosting içeriğinizi ve yapılandırmanızı belirtilen önizleme kanalına dağıtın.
Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
hosting:channel:list
|
Bir Hosting sitesinin tüm kanallarını ("canlı" kanal dahil) listeleme Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
hosting:channel:open \
|
Belirtilen kanalın URL'sini bir tarayıcıda açar veya tarayıcıda açmak mümkün değilse URL'yi döndürür. CLI etkileşimli olmayan modda çalışıyorsa CHANNEL_ID gereklidir. Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
| Sürüm kopyalama | |
hosting:clone \
|
Belirtilen "kaynak" kanalda en son dağıtılan sürümü belirtilen "hedef" kanala kopyalayın. Bu komut, belirtilen "hedef" kanala da dağıtım yapar. "Hedef" kanal henüz mevcut değilse bu komut, kanala dağıtım yapmadan önce "hedef" Hosting sitesinde yeni bir önizleme kanalı oluşturur. |
hosting:clone \
|
Belirtilen sürümü, belirtilen "hedef" kanala kopyalayın. Bu komut, belirtilen "hedef" kanala da dağıtım yapar. "Hedef" kanal henüz mevcut değilse bu komut, kanala dağıtım yapmadan önce "hedef" Hosting sitesinde yeni bir önizleme kanalı oluşturur. VERSION_ID bilgisini Firebase konsolunun Hosting kontrol panelinde bulabilirsiniz. |
Realtime Database komut
İlk, varsayılan Realtime Database örneğinizi Firebase konsolunda veya genel firebase init iş akışını ya da özel firebase init database akışını kullanarak oluşturabilirsiniz.
Örnekler oluşturulduktan sonra bunları CLI kullanarak belirli örnekleri yönetme ve bunlarla etkileşim kurma bölümünde açıklandığı şekilde yönetebilirsiniz.
| Komut | Açıklama |
|---|---|
database:get \
|
Belirtilen veritabanı konumunda (PATH) bir Realtime Database örneği için verileri alın ve JSON olarak gösterin. Dizine eklenen verilerde sorgulamayı destekler. Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
database:instances:create \
|
Belirtilen konumda belirtilen DATABASE_NAME ile bir Realtime Database örneği oluşturun. Bu komut, aşağıdaki isteğe bağlı (ancak önerilen) işareti destekler:
Etkin Firebase projesi için varsayılan Realtime Database örneğini oluşturmak üzere bu komutu kullanamazsınız. Projede mevcut Realtime Database örneği yoksa projenin ilk Realtime Database örneğini (varsayılan örnek) oluşturmak için |
database:instances:list
|
Etkin Firebase projesindeki tüm Realtime Database örneklerini listeler. Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
database:profile
|
Bir Realtime Database örneği için işlem profili oluşturun.
Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
database:push \
|
Belirtilen veritabanı konumundaki (PATH) bir listeye yeni veri aktarır. Bu işlem, bir Realtime Database örneğinde gerçekleştirilir.
Bir dosyadan (INFILE), STDIN'den veya Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
database:remove \
|
Bir Realtime Database örneğinde belirtilen veritabanı konumundaki (PATH) tüm verileri siler. Bu komut, aşağıdaki isteğe bağlı işareti destekler:
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin: |
database:set \
|
Realtime Database örneğinde belirtilen veritabanı konumundaki (PATH) tüm verileri değiştirin.
Bir dosyadan (INFILE), STDIN'den veya Bu komut, aşağıdaki isteğe bağlı işareti destekler:
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin: |
database:update \
|
Realtime Database örneğinde belirtilen veritabanı konumunda (PATH) kısmi güncelleme gerçekleştirin.
Bir dosyadan (INFILE), STDIN'den veya Bu komut, aşağıdaki isteğe bağlı işareti destekler:
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin: |
Remote Config komut
Bu komutlar ve kullanım alanları, Remote Config programatik olarak değiştirme bölümünde daha ayrıntılı olarak ele alınmıştır.
| Komut | Açıklama |
|---|---|
remoteconfig:versions:list
|
Remote Config şablonunun tüm sürümlerini listele. Bu komut, aşağıdaki isteğe bağlı işareti destekler:
|
remoteconfig:get \
|
Belirtilen sürümdeki Remote Config şablonunun ayrıntılarını alın. Bu komut, aşağıdaki isteğe bağlı (ancak önerilen) işaretleri destekler:
|
remoteconfig:rollback \
|
Remote Config şablonunu belirtilen önceki sürüme geri döndürün. Bu komut, aşağıdaki isteğe bağlı (ancak önerilen) işareti destekler:
CLI, harekete geçmeden önce bir onay istemi gösterir. Onay istemini atlamak için (etkileşimli modda gereklidir) şu işaretleri iletin: |
remoteconfig:experiments:list
|
Etkin Firebase projesindeki tüm Remote Config denemelerini listeler. Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
|
remoteconfig:experiments:get \
|
Belirtilen Remote Config denemesinin ayrıntılarını alın.
Tablo çıktısı; denemenin kaynak adını, görünen adını, durumunu ( |
remoteconfig:experiments:delete \
|
Belirtilen Remote Config denemesini siler.
CLI, işlem yapmadan önce bir onay istemi gösterir ve |
remoteconfig:rollouts:list
|
Etkin Firebase projesindeki tüm Remote Config kullanıma sunma işlemlerini listeler. Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
|
remoteconfig:rollouts:get \
|
Belirtilen Remote Config kullanıma sunma işleminin ayrıntılarını alın. |
remoteconfig:rollouts:delete \
|
Belirtilen Remote Config kullanıma sunumunu silin.
CLI, işlem yapmadan önce bir onay istemi gösterir ve |
SQL Connect komut
Bu komutlar ve kullanım alanları, SQL Connect CLI referans kılavuzunda daha ayrıntılı olarak ele alınmıştır.
| Komut | Açıklama |
|---|---|
dataconnect:services:list
|
Etkin Firebase projesinde dağıtılan tüm SQL Connect hizmetlerini listeler. |
dataconnect:sql:diff
|
Yerel bir SQL Connect şeması ile Cloud SQL veritabanı şemanız arasındaki farkları gösterir. Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
|
dataconnect:sql:migrate
|
Cloud SQL veritabanınızın şemasını yerel SQL Connect şemanızla eşleşecek şekilde taşıyın. Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
Etkileşimli modda KSA, işlem yapmadan önce bir onay istemi gösterir. Etkileşimli olmayan modda, yıkıcı olmayan taşıma işlemleri otomatik olarak çalıştırılır. Yıkıcı değişiklikler ise |
dataconnect:sql:grant \
|
Kullanıcı veya hizmet hesabının belirtilen EMAIL_ADDRESS öğesine belirtilen SQL_ROLE ( Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
|
dataconnect:sdk:generate
|
SQL Connect bağlayıcılarınız için yazılı SDK'lar oluşturun. Bu komut aşağıdaki isteğe bağlı işaretleri destekler:
|